@@ -1,5 +1,5 @@
 TEST_OLD_NFT_CONTRACT_ADDRESS = "0xedd431613Ae5EF32D006F2Ad1fC229d939f86C64"
-TEST_NFT_CONTRACT_ADDRESS = "0x08F218A226eCDb6D2a1a3c0155f90Fe905FD5e34"
+TEST_NFT_CONTRACT_ADDRESS = "0xE06118102dfe18930DE60A9C16c90Eefa8020B54"
 TEST_PACK_CONTRACT_ADDRESS = "0x54ec360704b2e9E4e6499a732b78094D6d78e37B"
 TEST_MARKET_CONTRACT_ADDRESS = "0x325a98B6081ef88C6356d63c56f48Fa1d0d2DD0D"
 TEST_BUNDLE_CONTRACT_ADDRESS = "0xc5392102B97496413fCCe4c823bF1F674856B382"
